Registracija | OiRA

Teme

# Registracija

## Zašto se trebam registrirati?

Kad započnete svoju prvu procjenu rizika, od vas će se najprije tražiti da kreirate račun u sustavu OiRA. Postupak je jednostavan i brz.

Nakon što se registrirate, u svakom ćete se trenutku moći prijaviti i pristupiti svojim podatcima, nastaviti s prethodnim procjenama ili pokrenuti nove procjene.

Registracija omogućuje da se sve vaše sesije spremaju u alatu OiRA i da su vam vaši podatci uvijek dostupni.

Pročitajte naša pravila zaštite privatnosti i doznajte kako obrađujemo vaše osobne podatke.

## Koja je razlika između registracije korisnika i pokretanja probne sesije?

Probna sesija omogućuje zainteresiranim stranama da pregledaju alat prije nego što se odluče registrirati. Međutim, vaši se podatci tijekom probne sesije neće spremati i kasnije nećete moći pristupiti informacijama koje ste unijeli. Tijekom probne sesije nećete moći ispisivati izvješća, a registracija korisnika omogućuje vam da dokumentirate svaki korak svoje procjene rizika.

## Registracija novog računa

Prvi ste put ovdje? Da biste započeli, slijedite ove jednostavne korake:

1. Kliknite na opciju „Registracija” za prikaz obrasca za registraciju.

Obrazac za registraciju.

1. Unesite svoju e-adresu i odaberite lozinku (dvaput).

2. Kliknite na opciju „Sljedeće” da biste registrirali novi račun.

3. Za nastavak pročitajte i prihvatite pravila zaštite privatnosti.

Time ćete se prijaviti u alat OiRA.

## Prijava u postojeći račun

Ako ste se već registrirali, svojem računu možete pristupiti na sljedeći način:

1. Otvorite obrazac za prijavu. Poveznica na obrazac za prijavu prikazat će se svaki put kad pokušate pristupiti sustavu OiRA, sve dok se ne prijavite.

Obrazac za prijavu.

1. Unesite svoju e-adresu i lozinku.

2. Prijavite se tako da kliknete na gumb „Prijava”.

Nakon što se prijavite, prikazat će se zaslon u nastavku. Na njemu možete pokrenuti novu procjenu rizika ili se vratiti na procjene koje ste prethodno pokrenuli.

Nadzorna ploča.

Pokrenite novu procjenu rizika tako što ćete joj odrediti naslov (npr. Moje-poduzeće 2018-07-03) ili pristupite jednoj od prethodnih procjena rizika. Ako ih ne odlučite izbrisati, sve vaše procjene rizika spremaju se za buduću uporabu.

Scroll to top Load toolbar…
Back

## 1-registration.md

Više

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More